@@ -1,6 +1,6 @@
 package Data::Format::Pretty::JSON;
 
-use 5.010;
+use 5.010001;
 use strict;
 use warnings;
 
@@ -8,7 +8,7 @@ require Exporter;
 our @ISA = qw(Exporter);
 our @EXPORT_OK = qw(format_pretty);
 
-our $VERSION = '0.06'; # VERSION
+our $VERSION = '0.07'; # VERSION
 
 sub content_type { "application/json" }
 
@@ -17,23 +17,31 @@ sub format_pretty {
     $opts //= {};
 
     state $json;
-
-    if ($opts->{color} // $ENV{COLOR} // (-t STDOUT)) {
+    my $pretty = $opts->{pretty} // 1;
+    my $linum  = $opts->{linum} // $ENV{LINUM} // $opts->{pretty};
+    my $color  = $opts->{color} // $ENV{COLOR} // (-t STDOUT);
+    if ($color) {
         require JSON::Color;
-        JSON::Color::encode_json($data, {pretty=>1, linum=>1}) . "\n";
+        JSON::Color::encode_json($data, {pretty=>$pretty, linum=>$linum})."\n";
     } else {
         if (!$json) {
             require JSON;
             $json = JSON->new->utf8->allow_nonref;
         }
-        $json->pretty($opts->{pretty} // 1);
-        $json->encode($data);
+        $json->pretty($pretty);
+        if ($linum) {
+            require SHARYANTO::String::Util;
+            SHARYANTO::String::Util::linenum($json->encode($data));
+        } else {
+            $json->encode($data);
+        }
     }
 }
 
 1;
 # ABSTRACT: Pretty-print data structure as JSON
 
+__END__
 
 =pod
 
@@ -43,7 +51,7 @@ Data::Format::Pretty::JSON - Pretty-print data structure as JSON
 
 =head1 VERSION
 
-version 0.06
+version 0.07
 
 =head1 SYNOPSIS
 
@@ -56,10 +64,14 @@ Some example output:
 
 =item * format_pretty({a=>1, b=>2})
 
-  {
-      "a" : 1,
-      "b" : 1,
-  }
+  1:{
+  2:    "a" : 1,
+  3:    "b" : 2,
+  4:}
+
+By default color is turned on (unless forced off via C<COLOR> environment) as
+well as pretty printing (unless turned off via pretty=>1) and line numbers
+(unless when pretty=>0 or turned off by linum=>0).
 
 =item * format_pretty({a=>1, b=>2}, {pretty=>0});
 
@@ -86,10 +98,14 @@ Return formatted data structure as JSON. Options:
 Whether to enable coloring. The default is the enable only when running
 interactively. Currently also enable line numbering.
 
-=item * pretty => BOOL (default 1)
+=item * pretty => BOOL (default: 1)
 
 Whether to pretty-print JSON.
 
+=item * linum => BOOL (default: 1 or 0 if pretty=0)
+
+Whether to add line numbers.
+
 =back
 
 =head2 content_type() => STR
@@ -102,6 +118,10 @@ Return C<application/json>.
 
 Set C<color> option (if unset).
 
+=head2 LINUM => BOOL
+
+Set C<linum> option (if unset).
+
 =head1 SEE ALSO
 
 L<Data::Format::Pretty>
@@ -112,14 +132,9 @@ Steven Haryanto <stevenharyanto@gmail.com>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2012 by Steven Haryanto.
+This software is copyright (c) 2013 by Steven Haryanto.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
 
 =cut
-
-
-__END__
-
-
